# WorkloadConfiguration

Configuration associated with Applications that have a workload (eg. container)

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**env_config_vars** | [**[EnvironmentConfigVar]**](EnvironmentConfigVar.md) | It stores an array of env_config_var objects(key &amp; value pairs) in API. It provides environment variables to build configmaps and secrets directly.  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


